# PEtab vis

An interactive visualization tool for
[PEtab](https://github.com/PEtab-dev/PEtab) measurement and simulation files.

## Installation

### From pypi

```shell
pip3 install petabvis
```

### From GitHub repository

```shell
pip3 install git+https://github.com/PEtab-dev/petab-interactive-viz.git@main
```

### From local source directory

From within the root source directory, run:

```shell
pip3 install .
```

## Usage

1. Run `petabvis`
2. Select a PEtab yaml file
3. Optionally select a PEtab measurement file
4. Navigate through the plots

See also `petabvis -h` for command line usage.
